import { h, Host, getAssetPath, createEvent, proxyCustomElement } from '@stencil/core/internal/client';

function api(url) {
    return fetch(url).then((response) => {
        if (!response.ok) {
            throw new Error(response.statusText);
        }
        return response.json();
    });
}

const suggestions = new Map();
/** requests suggestions from url and caches responses */
const getSuggestions = (url) => {
    if (suggestions.has(url)) {
        return Promise.resolve(suggestions.get(url));
    }
    return api(url).then((response) => {
        suggestions.set(url, response);
        return response;
    });
};

let globalIdCounter = 0;
const getUniqueId = () => {
    globalIdCounter++;
    return `ui-unique-id-${globalIdCounter}`;
};

const autosuggestInputCss = ".ui-autosuggest-input{display:block;position:relative}.ui-autosuggest-input__input-container{position:relative}.ui-autosuggest-input__suggestions{padding-top:44px;position:absolute;z-index:1;width:100%;top:0;left:0;-webkit-box-shadow:0 7px 22px rgba(19, 19, 19, 0.15);box-shadow:0 7px 22px rgba(19, 19, 19, 0.15);pointer-events:none}.ui-autosuggest-input__suggestions .ui-suggest-item{pointer-events:auto}.ui-autosuggest-input__suggestions--hidden{display:none}.ui-autosuggest-input__suggestion-link{text-decoration:none}.ui-autosuggest-input__suggestion-link:last-child .ui-suggest-item{border:0}";

class AutosuggestInput extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** placeholder text for input */
        this.placeholder = "";
        /** name attribute for input */
        this.name = "";
        /** id attribute for input. A unique id will be generated if this is empty */
        this.inputId = "";
        /** label for input */
        this.label = "";
        /** URL for autosuggest-API */
        this.url = "";
        this.suggestions = [];
        this.input = "";
        this.isHidden = true;
        this.id = "";
    }
    componentWillLoad() {
        const { inputId } = this;
        this.id = inputId || getUniqueId();
    }
    onInput(event) {
        if (this.url === "") {
            return;
        }
        const { value } = event.target;
        this.input = value;
        if (value === "") {
            this.suggestions = [];
            return;
        }
        getSuggestions(`${this.url}?q=${value}`)
            .then((response) => (this.suggestions = response))
            .catch((error) => console.error(error));
    }
    onBlur() {
        this.isHidden = true;
    }
    onFocus() {
        this.isHidden = false;
    }
    onClick(event, value) {
        event.preventDefault();
        const input = this.domNode.querySelector("input");
        input.value = value;
        this.suggestions = [];
    }
    render() {
        const baseClass = "ui-autosuggest-input";
        const { placeholder, name, suggestions, id, input, label, isHidden, } = this;
        return (h(Host, { class: baseClass, onFocusout: () => this.onBlur() }, label !== "" && (h("label", { class: "ui-label", htmlFor: id }, label)), h("div", { class: `${baseClass}__input-container` }, h("input", { class: "ui-input", name: name, type: "text", placeholder: placeholder, autocomplete: "off", autocapitalize: "off", id: id, onInput: (event) => this.onInput(event), onFocus: () => this.onFocus() }), h("div", { class: {
                [`${baseClass}__suggestions`]: true,
                [`${baseClass}__suggestions--hidden`]: isHidden,
            } }, suggestions === null || suggestions === void 0 ? void 0 : suggestions.map(({ value, description, image }) => (h("a", { class: `${baseClass}__suggestion-link`, href: "#", onFocus: () => this.onFocus(), onClick: (event) => this.onClick(event, value) }, h("ui-suggest-item", { text: value, input: input, subline: description, image: image }))))))));
    }
    get domNode() { return this; }
    static get watchers() { return {
        "inputId": ["componentWillLoad"]
    }; }
    static get style() { return autosuggestInputCss; }
}

const checkboxCss = ".ui-checkbox__wrapper{-ms-flex-align:center;align-items:center;cursor:pointer;display:-ms-inline-flexbox;display:inline-flex;position:relative;vertical-align:middle;width:100%}.ui-checkbox__input{opacity:0;position:absolute}.ui-checkbox__icon{background-position:center;background-repeat:no-repeat;display:inline-block;font-variant:normal;font-weight:normal;height:20px;line-height:1;speak:none;text-rendering:optimizeLegibility;text-transform:none;width:20px;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased}.ui-checkbox__icon--unchecked{background-image:url(\"data:image/svg+xml;charset%3DUS-ASCII,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2020%2020%22%20style%3D%22enable-background%3Anew%200%200%2020%2020%22%3E%3Cpath%20style%3D%22fill%3A%23010202%22%20d%3D%22M19%200H0v20h20V0h-1zm0%2019H1V1h18v18z%22%2F%3E%3C%2Fsvg%3E\")}.ui-checkbox__icon--checked{background-image:url(\"data:image/svg+xml;charset%3DUS-ASCII,%3Csvg%20data-name%3D%22Ebene%201%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2030%2030%22%3E%3Ctitle%3Echeckbox_checked%3C%2Ftitle%3E%3Cpath%20d%3D%22M29%200H0v30h30V0h-1zm-1%2028H2V2h26v26z%22%2F%3E%3Cpath%20d%3D%22M12.9%2019.91l1.05-1.04%208.88-8.89-1.04-1.04-8.89%208.88-4.18-4.18-1.04%201.05%204.18%204.18%201.04%201.04z%22%2F%3E%3C%2Fsvg%3E\")}.ui-checkbox__label{font-family:\"Frutiger-Bold\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;font-size:12px;line-height:20px;margin-left:10px;text-transform:uppercase}.ui-checkbox__input:not(:checked)~.ui-checkbox__icon--checked{display:none}.ui-checkbox__input:checked~.ui-checkbox__icon--unchecked{display:none}";

class Checkbox extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** value of the input element, not visible to the user */
        this.value = "";
        /** text inside the label element, visible to the user */
        this.label = "";
    }
    render() {
        return (h(Host, { class: "ui-checkbox" }, h("label", { class: "ui-checkbox__wrapper" }, h("input", { class: "ui-checkbox__input", type: "checkbox", value: this.value }), h("span", { class: "ui-checkbox__icon ui-checkbox__icon--unchecked" }), h("span", { class: "ui-checkbox__icon ui-checkbox__icon--checked" }), h("span", { class: "ui-checkbox__label" }, this.label))));
    }
    static get style() { return checkboxCss; }
}

const checkboxListItemCss = "ui-checkbox-list-item{}";

class CheckboxListItem extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
    }
    render() {
        return (h(Host, null, h("ui-checkbox", { value: this.value, label: this.label }), h("div", { style: { display: "none" } }, h("slot", null))));
    }
    static get style() { return checkboxListItemCss; }
}

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

function createCommonjsModule(fn, basedir, module) {
	return module = {
	  path: basedir,
	  exports: {},
	  require: function (path, base) {
    return commonjsRequire();
  }
	}, fn(module, module.exports), module.exports;
}

function commonjsRequire () {
	throw new Error('Dynamic requires are not currently supported by @rollup/plugin-commonjs');
}

var dayjs_min = createCommonjsModule(function (module, exports) {
!function(t,e){module.exports=e();}(commonjsGlobal,function(){var t="millisecond",e="second",n="minute",r="hour",i="day",s="week",u="month",o="quarter",a="year",h=/^(\d{4})-?(\d{1,2})-?(\d{0,2})[^0-9]*(\d{1,2})?:?(\d{1,2})?:?(\d{1,2})?.?(\d{1,3})?$/,f=/\[([^\]]+)]|Y{2,4}|M{1,4}|D{1,2}|d{1,4}|H{1,2}|h{1,2}|a|A|m{1,2}|s{1,2}|Z{1,2}|SSS/g,c=function(t,e,n){var r=String(t);return !r||r.length>=e?t:""+Array(e+1-r.length).join(n)+t},d={s:c,z:function(t){var e=-t.utcOffset(),n=Math.abs(e),r=Math.floor(n/60),i=n%60;return (e<=0?"+":"-")+c(r,2,"0")+":"+c(i,2,"0")},m:function(t,e){var n=12*(e.year()-t.year())+(e.month()-t.month()),r=t.clone().add(n,u),i=e-r<0,s=t.clone().add(n+(i?-1:1),u);return Number(-(n+(e-r)/(i?r-s:s-r))||0)},a:function(t){return t<0?Math.ceil(t)||0:Math.floor(t)},p:function(h){return {M:u,y:a,w:s,d:i,D:"date",h:r,m:n,s:e,ms:t,Q:o}[h]||String(h||"").toLowerCase().replace(/s$/,"")},u:function(t){return void 0===t}},$={name:"en",weekdays:"Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"),months:"January_February_March_April_May_June_July_August_September_October_November_December".split("_")},l="en",m={};m[l]=$;var y=function(t){return t instanceof v},M=function(t,e,n){var r;if(!t)return l;if("string"==typeof t)m[t]&&(r=t),e&&(m[t]=e,r=t);else {var i=t.name;m[i]=t,r=i;}return !n&&r&&(l=r),r||!n&&l},g=function(t,e){if(y(t))return t.clone();var n="object"==typeof e?e:{};return n.date=t,n.args=arguments,new v(n)},D=d;D.l=M,D.i=y,D.w=function(t,e){return g(t,{locale:e.$L,utc:e.$u,$offset:e.$offset})};var v=function(){function c(t){this.$L=this.$L||M(t.locale,null,!0),this.parse(t);}var d=c.prototype;return d.parse=function(t){this.$d=function(t){var e=t.date,n=t.utc;if(null===e)return new Date(NaN);if(D.u(e))return new Date;if(e instanceof Date)return new Date(e);if("string"==typeof e&&!/Z$/i.test(e)){var r=e.match(h);if(r)return n?new Date(Date.UTC(r[1],r[2]-1,r[3]||1,r[4]||0,r[5]||0,r[6]||0,r[7]||0)):new Date(r[1],r[2]-1,r[3]||1,r[4]||0,r[5]||0,r[6]||0,r[7]||0)}return new Date(e)}(t),this.init();},d.init=function(){var t=this.$d;this.$y=t.getFullYear(),this.$M=t.getMonth(),this.$D=t.getDate(),this.$W=t.getDay(),this.$H=t.getHours(),this.$m=t.getMinutes(),this.$s=t.getSeconds(),this.$ms=t.getMilliseconds();},d.$utils=function(){return D},d.isValid=function(){return !("Invalid Date"===this.$d.toString())},d.isSame=function(t,e){var n=g(t);return this.startOf(e)<=n&&n<=this.endOf(e)},d.isAfter=function(t,e){return g(t)<this.startOf(e)},d.isBefore=function(t,e){return this.endOf(e)<g(t)},d.$g=function(t,e,n){return D.u(t)?this[e]:this.set(n,t)},d.year=function(t){return this.$g(t,"$y",a)},d.month=function(t){return this.$g(t,"$M",u)},d.day=function(t){return this.$g(t,"$W",i)},d.date=function(t){return this.$g(t,"$D","date")},d.hour=function(t){return this.$g(t,"$H",r)},d.minute=function(t){return this.$g(t,"$m",n)},d.second=function(t){return this.$g(t,"$s",e)},d.millisecond=function(e){return this.$g(e,"$ms",t)},d.unix=function(){return Math.floor(this.valueOf()/1e3)},d.valueOf=function(){return this.$d.getTime()},d.startOf=function(t,o){var h=this,f=!!D.u(o)||o,c=D.p(t),d=function(t,e){var n=D.w(h.$u?Date.UTC(h.$y,e,t):new Date(h.$y,e,t),h);return f?n:n.endOf(i)},$=function(t,e){return D.w(h.toDate()[t].apply(h.toDate("s"),(f?[0,0,0,0]:[23,59,59,999]).slice(e)),h)},l=this.$W,m=this.$M,y=this.$D,M="set"+(this.$u?"UTC":"");switch(c){case a:return f?d(1,0):d(31,11);case u:return f?d(1,m):d(0,m+1);case s:var g=this.$locale().weekStart||0,v=(l<g?l+7:l)-g;return d(f?y-v:y+(6-v),m);case i:case"date":return $(M+"Hours",0);case r:return $(M+"Minutes",1);case n:return $(M+"Seconds",2);case e:return $(M+"Milliseconds",3);default:return this.clone()}},d.endOf=function(t){return this.startOf(t,!1)},d.$set=function(s,o){var h,f=D.p(s),c="set"+(this.$u?"UTC":""),d=(h={},h[i]=c+"Date",h.date=c+"Date",h[u]=c+"Month",h[a]=c+"FullYear",h[r]=c+"Hours",h[n]=c+"Minutes",h[e]=c+"Seconds",h[t]=c+"Milliseconds",h)[f],$=f===i?this.$D+(o-this.$W):o;if(f===u||f===a){var l=this.clone().set("date",1);l.$d[d]($),l.init(),this.$d=l.set("date",Math.min(this.$D,l.daysInMonth())).toDate();}else d&&this.$d[d]($);return this.init(),this},d.set=function(t,e){return this.clone().$set(t,e)},d.get=function(t){return this[D.p(t)]()},d.add=function(t,o){var h,f=this;t=Number(t);var c=D.p(o),d=function(e){var n=g(f);return D.w(n.date(n.date()+Math.round(e*t)),f)};if(c===u)return this.set(u,this.$M+t);if(c===a)return this.set(a,this.$y+t);if(c===i)return d(1);if(c===s)return d(7);var $=(h={},h[n]=6e4,h[r]=36e5,h[e]=1e3,h)[c]||1,l=this.$d.getTime()+t*$;return D.w(l,this)},d.subtract=function(t,e){return this.add(-1*t,e)},d.format=function(t){var e=this;if(!this.isValid())return "Invalid Date";var n=t||"YYYY-MM-DDTHH:mm:ssZ",r=D.z(this),i=this.$locale(),s=this.$H,u=this.$m,o=this.$M,a=i.weekdays,h=i.months,c=function(t,r,i,s){return t&&(t[r]||t(e,n))||i[r].substr(0,s)},d=function(t){return D.s(s%12||12,t,"0")},$=i.meridiem||function(t,e,n){var r=t<12?"AM":"PM";return n?r.toLowerCase():r},l={YY:String(this.$y).slice(-2),YYYY:this.$y,M:o+1,MM:D.s(o+1,2,"0"),MMM:c(i.monthsShort,o,h,3),MMMM:c(h,o),D:this.$D,DD:D.s(this.$D,2,"0"),d:String(this.$W),dd:c(i.weekdaysMin,this.$W,a,2),ddd:c(i.weekdaysShort,this.$W,a,3),dddd:a[this.$W],H:String(s),HH:D.s(s,2,"0"),h:d(1),hh:d(2),a:$(s,u,!0),A:$(s,u,!1),m:String(u),mm:D.s(u,2,"0"),s:String(this.$s),ss:D.s(this.$s,2,"0"),SSS:D.s(this.$ms,3,"0"),Z:r};return n.replace(f,function(t,e){return e||l[t]||r.replace(":","")})},d.utcOffset=function(){return 15*-Math.round(this.$d.getTimezoneOffset()/15)},d.diff=function(t,h,f){var c,d=D.p(h),$=g(t),l=6e4*($.utcOffset()-this.utcOffset()),m=this-$,y=D.m(this,$);return y=(c={},c[a]=y/12,c[u]=y,c[o]=y/3,c[s]=(m-l)/6048e5,c[i]=(m-l)/864e5,c[r]=m/36e5,c[n]=m/6e4,c[e]=m/1e3,c)[d]||m,f?y:D.a(y)},d.daysInMonth=function(){return this.endOf(u).$D},d.$locale=function(){return m[this.$L]},d.locale=function(t,e){if(!t)return this.$L;var n=this.clone(),r=M(t,e,!0);return r&&(n.$L=r),n},d.clone=function(){return D.w(this.$d,this)},d.toDate=function(){return new Date(this.valueOf())},d.toJSON=function(){return this.isValid()?this.toISOString():null},d.toISOString=function(){return this.$d.toISOString()},d.toString=function(){return this.$d.toUTCString()},c}();return g.prototype=v.prototype,g.extend=function(t,e){return t(e,v,g),g},g.locale=M,g.isDayjs=y,g.unix=function(t){return g(1e3*t)},g.en=m[l],g.Ls=m,g});
});

var utc = createCommonjsModule(function (module, exports) {
!function(t,i){module.exports=i();}(commonjsGlobal,function(){return function(t,i,e){var s=(new Date).getTimezoneOffset(),n=i.prototype;e.utc=function(t){return new i({date:t,utc:!0,args:arguments})},n.utc=function(){return e(this.toDate(),{locale:this.$L,utc:!0})},n.local=function(){return e(this.toDate(),{locale:this.$L,utc:!1})};var u=n.parse;n.parse=function(t){t.utc&&(this.$u=!0),this.$utils().u(t.$offset)||(this.$offset=t.$offset),u.call(this,t);};var o=n.init;n.init=function(){if(this.$u){var t=this.$d;this.$y=t.getUTCFullYear(),this.$M=t.getUTCMonth(),this.$D=t.getUTCDate(),this.$W=t.getUTCDay(),this.$H=t.getUTCHours(),this.$m=t.getUTCMinutes(),this.$s=t.getUTCSeconds(),this.$ms=t.getUTCMilliseconds();}else o.call(this);};var f=n.utcOffset;n.utcOffset=function(t){var i=this.$utils().u;if(i(t))return this.$u?0:i(this.$offset)?f.call(this):this.$offset;var e,n=Math.abs(t)<=16?60*t:t;return 0!==t?(e=this.local().add(n+s,"minute")).$offset=n:e=this.utc(),e};var r=n.format;n.format=function(t){var i=t||(this.$u?"YYYY-MM-DDTHH:mm:ss[Z]":"");return r.call(this,i)},n.valueOf=function(){var t=this.$utils().u(this.$offset)?0:this.$offset+s;return this.$d.valueOf()-6e4*t},n.isUTC=function(){return !!this.$u},n.toISOString=function(){return this.toDate().toISOString()},n.toString=function(){return this.toDate().toUTCString()};var a=n.toDate;n.toDate=function(t){return "s"===t&&this.$offset?e(this.format("YYYY-MM-DD HH:mm:ss:SSS")).toDate():a.call(this)};}});
});

dayjs_min.extend(utc);
class DateTime extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** UTC time in a ISO_8601 Format https://en.wikipedia.org/wiki/ISO_8601 example: 2020-05-20 17:32:33 */
        this.utc = "";
        /** Format String according to https://day.js.org/docs/en/display/format example: "DD.MM.YYYY HH:mm". You can escape characters by wrapping them in []. For now this webcomponent displays localized parts in a date like "Monday" only in English */
        this.format = "";
        /** Holds the final result */
        this.formattedDateTime = "";
    }
    componentWillLoad() {
        const { utc, format } = this;
        if (utc === "" || format === "") {
            this.formattedDateTime = "";
            return;
        }
        const utcDate = dayjs_min.utc(utc);
        if (!utcDate.isValid()) {
            console.error(`ui-date-time received an invalid date. UTC: "${utc}"`);
            this.formattedDateTime = "";
            return;
        }
        this.formattedDateTime = utcDate.local().format(format);
    }
    render() {
        return h(Host, { class: "ui-date-time" }, this.formattedDateTime);
    }
    static get watchers() { return {
        "utc": ["componentWillLoad"],
        "format": ["componentWillLoad"]
    }; }
}

const dropdownCss = ".ui-dropdown{font-family:\"Frutiger-Bold\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;display:block;font-size:12px;position:relative;text-transform:uppercase}.ui-dropdown__label{-ms-flex-align:center;align-items:center;border:1px solid #131313;cursor:pointer;display:-ms-flexbox;display:flex;-ms-flex-pack:justify;justify-content:space-between;padding:13px 25px}.ui-dropdown__label svg{height:15px;-webkit-transform:rotate(0deg);transform:rotate(0deg);-webkit-transition:-webkit-transform 250ms ease-in-out;transition:-webkit-transform 250ms ease-in-out;transition:transform 250ms ease-in-out;transition:transform 250ms ease-in-out, -webkit-transform 250ms ease-in-out;width:15px}.ui-dropdown__dropdown-locator{position:absolute;top:calc(100% - 1px);-webkit-transform:scaleY(0);transform:scaleY(0);-webkit-transform-origin:top;transform-origin:top;-webkit-transition:-webkit-transform 250ms ease-in-out;transition:-webkit-transform 250ms ease-in-out;transition:transform 250ms ease-in-out;transition:transform 250ms ease-in-out, -webkit-transform 250ms ease-in-out;width:100%}.ui-dropdown__menu{background-color:#fff;border:1px solid #131313;border-top:0}.ui-dropdown__menu .ui-list__filter-input{border-right:0;border-left:0;margin-bottom:10px;padding-left:25px;padding-right:25px}.ui-dropdown__list>li{padding:0 25px}.ui-dropdown.ui-dropdown--down .ui-dropdown__label svg{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.ui-dropdown.ui-dropdown--down .ui-dropdown__dropdown-locator{-webkit-transform:scaleY(1);transform:scaleY(1)}";

class Dropdown extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.isOpen = false;
        /** Text displayed on the Dropdown */
        this.label = "";
        /** Name Identifies the dropdown in a bigger context (for example in forms, filters) */
        this.name = "";
        /** This toggles the text-input to filter the dropdown items */
        this.filterable = false;
    }
    handleBodyClick(event) {
        if (!this.domNode.contains(event.target)) {
            this.isOpen = false;
        }
    }
    onLabelClick() {
        this.isOpen = !this.isOpen;
    }
    render() {
        return (h(Host, { class: {
                "ui-dropdown": true,
                "ui-dropdown--down": this.isOpen,
            } }, h("span", { class: "ui-dropdown__label", onClick: this.onLabelClick.bind(this) }, this.label, h("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 18.385 10.607" }, h("path", { d: "M16.971 0L9.192 7.778 1.414 0 0 1.414l7.778 7.778 1.414 1.415 1.415-1.415 7.778-7.778z" }))), h("div", { class: "ui-dropdown__dropdown-locator" }, h("ui-list", { filterable: this.filterable, class: "ui-dropdown__menu" }, h("slot", null)))));
    }
    get domNode() { return this; }
    static get style() { return dropdownCss; }
}

/**
 * Polyfill for Element APIs for IE11
 * from https://developer.mozilla.org/en-US/docs/Web/API/Element/closest#Polyfill
 */
const applyPolyfills = () => {
    if (!Element.prototype.matches) {
        Element.prototype.matches =
            Element.prototype.msMatchesSelector ||
                Element.prototype.webkitMatchesSelector;
    }
    if (!Element.prototype.closest) {
        Element.prototype.closest = function (s) {
            var el = this;
            do {
                if (Element.prototype.matches.call(el, s))
                    return el;
                el = el.parentElement || el.parentNode;
            } while (el !== null && el.nodeType === 1);
            return null;
        };
    }
};

applyPolyfills();
const referenceAttr = "data-reference";
class Filter extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
    }
    tagRemovedHandler(event) {
        const checkbox = this.domNode.querySelector(`input[type="checkbox"][${referenceAttr}="${event.detail}"]`);
        if (checkbox !== null) {
            checkbox.checked = false;
        }
    }
    onChange(e) {
        const checkbox = e.target;
        if (!checkbox.matches('input[type="checkbox"]')) {
            return;
        }
        if (checkbox.matches(`:not(:checked)[${referenceAttr}]`)) {
            const reference = checkbox.getAttribute(referenceAttr);
            const tags = this.domNode.querySelectorAll(`ui-tag[reference="${reference}"]`);
            [].forEach.call(tags, (tag) => tag.remove());
        }
        else {
            const reference = getUniqueId();
            checkbox.setAttribute(referenceAttr, reference);
            const labelText = checkbox.closest("label").innerText;
            const tagList = this.domNode.querySelector(".ui-tag-list");
            const tag = document.createElement("ui-tag");
            tag.setAttribute("reference", reference);
            tag.innerText = labelText;
            tagList.appendChild(tag);
        }
    }
    componentDidLoad() {
        this.initFilters();
    }
    initFilters() {
        if (typeof this.endpoint !== "string" || this.endpoint === "") {
            // TODO: uninit/reset
            return;
        }
        fetch(this.endpoint)
            .then((r) => r.json())
            .then((response) => {
            this.filterValues = response.filterValues;
            this.domNode.querySelectorAll("ui-dropdown").forEach((item) => {
                if (item.matches("[name]")) {
                    new Array(response.filterValues[item.getAttribute("name")]).forEach((filterValuesInfo) => {
                        // @ts-ignore
                        item.querySelector("ui-list").setFilterValues(filterValuesInfo);
                    });
                }
            });
        });
    }
    render() {
        return (h(Host, null, h("form", { onSubmit: (e) => e.preventDefault(), onChange: (e) => this.onChange(e) }, h("slot", null))));
    }
    get domNode() { return this; }
    static get watchers() { return {
        "endpoint": ["initFilters"]
    }; }
}

const isStr = (val) => typeof val === "string";

const validateContent = (svgContent) => {
    if (svgContent && typeof document !== "undefined") {
        const div = document.createElement("div");
        div.innerHTML = svgContent;
        // setup this way to ensure it works on IE
        for (let i = div.childNodes.length - 1; i >= 0; i--) {
            if (div.childNodes[i].nodeName.toLowerCase() !== "svg") {
                div.removeChild(div.childNodes[i]);
            }
        }
        // must only have 1 root element
        const svgElm = div.firstElementChild;
        if (svgElm && svgElm.nodeName.toLowerCase() === "svg") {
            const svgClass = svgElm.getAttribute("class") || "";
            svgElm.setAttribute("class", (svgClass + " ui-icon__svg").trim());
            svgElm.removeAttribute("id");
            // remove title element to prevent a bug where the svg title was treated as the page title
            const title = svgElm.querySelector("title");
            if (title !== null) {
                title.remove();
            }
            // root element must be an svg
            // lets double check we've got valid elements
            // do not allow scripts
            if (isValid(svgElm)) {
                return div.innerHTML;
            }
        }
    }
    return "";
};
const isValid = (elm) => {
    if (elm.nodeType === 1) {
        if (elm.nodeName.toLowerCase() === "script") {
            return false;
        }
        for (let i = 0; i < elm.attributes.length; i++) {
            const attr = elm.attributes[i];
            if (typeof attr !== "undefined") {
                const val = elm.attributes[i].name;
                if (isStr(val) && val.toLowerCase().indexOf("on") === 0) {
                    return false;
                }
            }
        }
        for (let i = 0; i < elm.childNodes.length; i++) {
            if (!isValid(elm.childNodes[i])) {
                return false;
            }
        }
    }
    return true;
};

const iconContent = new Map();
const requests = new Map();
const getSvgContent = (url) => {
    // see if we already have a request for this url
    let req = requests.get(url);
    if (!req) {
        // we don't already have a request
        req = fetch(url).then((rsp) => {
            if (rsp.ok) {
                return rsp.text().then((svgContent) => {
                    iconContent.set(url, validateContent(svgContent));
                });
            }
            iconContent.set(url, "");
        });
        // cache for the same requests
        requests.set(url, req);
    }
    return req;
};

const availableIcons = [
    "arrow-down",
    "arrow-right",
    "arrow-small-right",
    "cart",
    "case-in-progress",
    "circle-filled",
    "checkmark-rounded-thin",
    "cog",
    "documents",
    "hourglass-circle-arrow",
    "mail-denied",
    "order-status-package-checkmark",
    "watchlist",
    "wrench",
    "wrench-checkmark",
];

const iconCss = ".ui-icon{display:inline-block;vertical-align:middle}.ui-icon__inner{width:1em;height:1em;display:block}.ui-icon__svg{width:100%;height:100%;display:block}";

/**
 * this component is heavily inspired by https://github.com/ionic-team/ionicons
 */
class Icon extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** name of icon */
        this.name = "";
        /** contains the full svg */
        this.svgContent = null;
    }
    connectedCallback() {
        this.loadIcon();
    }
    loadIcon() {
        if (this.name === "") {
            return;
        }
        if (availableIcons.indexOf(this.name) === -1) {
            console.warn(`Icon ${this.name} is not available in ui-icon.`);
            return;
        }
        const url = getAssetPath(`./assets/${this.name}.svg`);
        if (iconContent.has(url)) {
            // sync if it's already loaded
            this.svgContent = iconContent.get(url);
        }
        else {
            // async if it hasn't been loaded
            getSvgContent(url).then(() => (this.svgContent = iconContent.get(url)));
        }
    }
    render() {
        if (this.name === "" || this.svgContent === null) {
            return null;
        }
        return (h(Host, { class: "ui-icon" }, h("div", { class: "ui-icon__inner", innerHTML: this.svgContent })));
    }
    static get assetsDirs() { return ["assets"]; }
    static get watchers() { return {
        "name": ["loadIcon"]
    }; }
    static get style() { return iconCss; }
}

const listCss = "ui-list{display:block}ui-list>ul{list-style-type:none;padding:0;margin:0}ui-list>ul>li{padding:0 15px}ui-list .ui-dropdown__item--hidden{display:none}";

class List extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** enables the search field inside the list */
        this.filterable = false;
        this.items = [];
        this.filterString = "";
    }
    /** set the Content from outside */
    async setFilterValues(filterValues) {
        this.items = filterValues;
    }
    componentWillLoad() {
        this.children = Array.from(this.domNode.children);
    }
    onFilterChange(event) {
        this.filterString = event.target.value.toLowerCase();
    }
    render() {
        const filterInput = this.filterable && (h("div", { class: "ui-list__filter" }, h("input", { class: "ui-list__filter-input", type: "text", placeholder: "Search", onKeyUp: this.onFilterChange.bind(this) })));
        const hasItems = this.items.length > 0;
        const filter = (itemName) => {
            return (this.filterString.length === 0 ||
                itemName.toLowerCase().indexOf(this.filterString) !== -1);
        };
        return (h(Host, null, filterInput, h("ul", { class: "ui-dropdown__list" }, hasItems &&
            this.items.map((item) => (h("li", { class: {
                    "ui-dropdown__item--hidden": !filter(item.label),
                } }, h("ui-checkbox-list-item", { label: item.label, value: item.value })))), !hasItems &&
            this.children.map((child) => (h("li", { innerHTML: child.outerHTML, class: {
                    "ui-dropdown__item--hidden": !filter(child.getAttribute("label")),
                } })))), h("div", { style: { display: "none" } }, h("slot", null))));
    }
    get domNode() { return this; }
    static get style() { return listCss; }
}

const getValidatedValue = (newValue, oldValue, max, min) => {
    const newNumber = +newValue;
    if (isNaN(newNumber)) {
        return oldValue;
    }
    if (!isNaN(max) && newNumber > max) {
        return max;
    }
    if (!isNaN(min) && newNumber < min) {
        return min;
    }
    return Math.round(newNumber);
};
const calculateValue = (type, value, increment, max, min) => {
    const factor = type === "decrement" ? -1 : 1;
    const newValue = value + factor * increment;
    return getValidatedValue(newValue, value, max, min);
};
const getNumberValue = (string) => {
    const number = string === "" ? NaN : +string;
    return number;
};

const numberInputCss = ".ui-number-input{display:-ms-flexbox;display:flex;border:1px solid black}.ui-number-input__input[type=number]{text-align:center;padding:12px 10px;-ms-flex:1 1 0px;flex:1 1 0;width:auto;min-width:45px;border-radius:0;border:1px solid black;border-top-width:0;border-bottom-width:0;appearance:none;-webkit-appearance:none;-moz-appearance:textfield}.ui-number-input__input[type=number]::-webkit-outer-spin-button,.ui-number-input__input[type=number]::-webkit-inner-spin-button{-webkit-appearance:none;appearance:none}.ui-number-input__btn{-webkit-appearance:none;-moz-appearance:none;appearance:none;border:0;background:#e7e7e7;min-width:45px;-ms-flex:0 1 45px;flex:0 1 45px;text-align:center;border-radius:0}";

class NumberInput extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** name attribute for the input */
        this.name = "";
        /** initial value for the input */
        this.initialValue = "0";
        /** size of increment/decrement for the plus/minus button */
        this.step = "1";
        /** max value */
        this.max = "";
        /** min value */
        this.min = "";
    }
    componentWillLoad() {
        const { initialValue } = this;
        const initialNumber = +initialValue;
        if (!isNaN(initialNumber)) {
            this.value = initialNumber;
        }
        this.setNumbers();
    }
    setNumbers() {
        const { max, min, step } = this;
        this.minValue = getNumberValue(min);
        this.maxValue = getNumberValue(max);
        const stepValue = getNumberValue(step);
        this.stepValue = isNaN(stepValue) ? 1 : stepValue;
    }
    handlePlus() {
        this.changeValue("increment");
    }
    handleMinus() {
        this.changeValue("decrement");
    }
    changeValue(type = "increment") {
        const { stepValue, maxValue, minValue, value } = this;
        this.value = calculateValue(type, value, stepValue, maxValue, minValue);
    }
    onChange(event) {
        const { maxValue, minValue } = this;
        const { value } = event.target;
        this.value = getValidatedValue(value, this.value, maxValue, minValue);
        event.target.value = this.value;
    }
    render() {
        const baseClass = "ui-number-input";
        const { name, max, min, stepValue, value } = this;
        return (h(Host, { class: baseClass }, h("button", { type: "button", class: `${baseClass}__btn`, onClick: () => this.handleMinus() }, "\u2013"), h("input", { class: `${baseClass}__input`, name: name, step: stepValue.toString(), type: "number", max: max, min: min, value: value, onInput: (event) => this.onChange(event) }), h("button", { type: "button", class: `${baseClass}__btn`, onClick: () => this.handlePlus() }, "+")));
    }
    get domNode() { return this; }
    static get watchers() { return {
        "min": ["setNumbers"],
        "max": ["setNumbers"],
        "step": ["setNumbers"]
    }; }
    static get style() { return numberInputCss; }
}

function scrollToTopFallBack() {
    if (window.scrollY !== 0) {
        setTimeout(() => {
            window.scroll(0, window.scrollY - 40);
            scrollToTopFallBack();
        }, 20);
    }
}
function scrollToTop() {
    let behaviorSupported = false;
    try {
        window.scroll({
            // @ts-ignore
            get behavior() {
                behaviorSupported = true;
                return "smooth";
            },
        });
    }
    catch (err) {
        console.error(err);
    }
    if (behaviorSupported) {
        window.scroll({
            top: 0,
            behavior: "smooth",
        });
    }
    else {
        scrollToTopFallBack();
    }
}

const scrollToTopButtonCss = ".ui-scrollToTopButton{min-height:44px;min-width:44px;padding:9px 12px 7px}.ui-scrollToTopButton:hover svg{fill:#fff}";

class ScrollToTopButton extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
    }
    render() {
        return (h("button", { class: "ui-scrollToTopButton ui-button", onClick: () => scrollToTop() }, h("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 8.073 20.046", height: "20", width: "8" }, h("path", { d: "M4.033 0L0 4.033l.707.706L3.536 1.91v18.136h1V1.91l2.83 2.829.707-.706L4.04 0l-.004.004z" }))));
    }
    static get style() { return scrollToTopButtonCss; }
}

class Select extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.changeEventDetail = createEvent(this, "ui-selectChange", 7);
    }
    /** function to emit new active option value */
    selectChange(newValue) {
        this.changeEventDetail.emit(newValue.value);
    }
    render() {
        return (h(Host, { class: "ui-select" }, h("ui-icon", { class: "ui-select__icon", name: "arrow-down" }), h("select", { class: "ui-select__select", onChange: (e) => this.selectChange(e.target) }, h("slot", null))));
    }
}

/** returns the matched part and the remaining part of the text */
const getSuggestionHighlight = (input, text) => {
    const firstPart = text.substring(0, input.length);
    if (firstPart.toLowerCase() !== input.toLowerCase()) {
        return ["", text];
    }
    const matchedString = firstPart;
    const remaining = text.substring(input.length);
    return [matchedString, remaining];
};

const suggestItemCss = ".ui-suggest-item{font-family:\"Frutiger-Light\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;display:-ms-flexbox;display:flex;border-bottom:solid 1px #c4c4c4;color:#393939;background-color:#fff}.ui-suggest-item__image{width:75px;height:75px;background-size:cover;background-color:#e7e7e7}.ui-suggest-item__text-container{padding:15px}.ui-suggest-item__highlight{color:#bbd03a}.ui-suggest-item__subline{text-transform:uppercase}";

class SuggestItem extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** search query that will be highlighted in the text */
        this.input = "";
        /** suggestion text that matches the input */
        this.text = "";
        /** subline below the text */
        this.subline = "";
        /** optional image URL */
        this.image = "";
    }
    render() {
        const baseClass = "ui-suggest-item";
        const { text, subline, image, input } = this;
        const [highlight, remaining] = getSuggestionHighlight(input, text);
        return (h(Host, { class: baseClass }, image !== "" && (h("div", { class: `${baseClass}__image`, style: { backgroundImage: `url(${image})` } })), h("div", { class: `${baseClass}__text-container` }, h("div", { class: `${baseClass}__text` }, h("span", { class: `${baseClass}__highlight` }, highlight), remaining), h("div", { class: `${baseClass}__subline ui-text-tiny ui-text-tiny--bold` }, subline))));
    }
    static get style() { return suggestItemCss; }
}

const tabCss = ".ui-tab{display:none}.ui-tab.is-active{display:block}";

class Tab extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** Sets the name for the corresponding tab-button */
        this.name = "";
        /** Sets ID for Tab */
        this.tabId = "";
        /** Boolean to indicate active tab */
        this.active = false;
    }
    setActiveTab(event) {
        this.active = event.detail === this.tabId;
    }
    render() {
        return (h(Host, { class: `ui-tab ${this.active ? "is-active" : ""}` }, h("slot", null)));
    }
    get domNode() { return this; }
    static get style() { return tabCss; }
}

const tabButtonCss = ".ui-tab-button{display:-ms-inline-flexbox;display:inline-flex}.ui-tab-button+.ui-tab-button{margin-left:5px}.ui-tab-button__label{color:#131313;cursor:pointer;display:block;padding:8px 10px;position:relative;-webkit-transition:color 250ms ease-in-out;transition:color 250ms ease-in-out}.ui-tab-button__label::after{background-color:#bbd03a;content:\"\";display:block;height:3px;position:absolute;bottom:0;left:0;-webkit-transform:scaleX(0);transform:scaleX(0);-webkit-transform-origin:center;transform-origin:center;-webkit-transition:-webkit-transform 250ms ease-in-out;transition:-webkit-transform 250ms ease-in-out;transition:transform 250ms ease-in-out;transition:transform 250ms ease-in-out, -webkit-transform 250ms ease-in-out;width:100%}.ui-tab-button__label:hover{color:#595959}.ui-tab-button__label:hover::after{-webkit-transform:scaleX(1);transform:scaleX(1)}.ui-tab-button.is-active .ui-tab-button__label::after{-webkit-transform:scaleX(1);transform:scaleX(1)}";

class TabButton extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** Displays the label of the tab */
        this.name = "";
        /** Contains this tabs ID */
        this.tabId = "";
        this.active = false;
    }
    componentWillLoad() {
        this.active = this.activeTab === this.tabId;
    }
    render() {
        return (h(Host, { class: `ui-tab-button ${this.active ? "is-active" : ""}` }, h("div", { class: "ui-tab-button__label", id: this.tabId }, this.name)));
    }
    get domNode() { return this; }
    static get watchers() { return {
        "activeTab": ["componentWillLoad"]
    }; }
    static get style() { return tabButtonCss; }
}

const tabContainerCss = ".ui-tab-container__tab-header{-ms-flex-pack:start;justify-content:flex-start;border-bottom:1px solid #c4c4c4;display:-ms-flexbox;display:flex}.ui-tab-container__tab-body{padding-top:15px}";

class TabContainer extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** prop which holds the active tab id */
        this.activeTabId = "";
        this.activeTabEvent = createEvent(this, "ui-setActiveTab", 7);
    }
    /** id of the tab which will be active */
    setActiveTab(id) {
        this.activeTabId = id;
        this.activeTabEvent.emit(id);
    }
    componentWillLoad() {
        var _a;
        const children = Array.from(this.domNode.children);
        this.children = children;
        if (this.activeTabId !== "") {
            this.setActiveTab(this.activeTabId);
        }
        else {
            this.setActiveTab((_a = this.children[0]) === null || _a === void 0 ? void 0 : _a.tabId);
        }
    }
    render() {
        return (h(Host, { class: "ui-tab-container" }, h("div", { class: "ui-tab-container__tab-header" }, this.children.map((tab) => (h("ui-tab-button", { onClick: () => this.setActiveTab(tab.tabId), name: tab.name, tabId: tab.tabId, activeTab: this.activeTabId })))), h("div", { class: "ui-tab-container__tab-body" }, h("slot", null))));
    }
    get domNode() { return this; }
    static get style() { return tabContainerCss; }
}

class Tag extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.remove = createEvent(this, "remove", 7);
    }
    removeTag() {
        this.remove.emit(this.reference);
        this.domNode.remove();
    }
    render() {
        return (h(Host, null, h("span", { class: "ui-tag", onClick: (e) => {
                e.preventDefault();
                this.removeTag();
            } }, h("span", { class: "ui-tag__label" }, h("slot", null)), h("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 29.7 29.7" }, h("path", { d: "M29.7 1.41L28.28 0 14.85 13.44 1.41 0 0 1.41l13.44 13.44L0 28.28l1.41 1.42 13.44-13.44L28.28 29.7l1.42-1.42-13.44-13.43L29.7 1.41z" })))));
    }
    get domNode() { return this; }
}

const widgetEmptyCss = ".ui-widget-empty{overflow:hidden;width:100%}.ui-widget-empty__background{position:absolute;font-size:500px;top:10px;left:50px;opacity:0.04}.ui-widget-empty__background [fill]{fill:#131313}.ui-widget-empty__inner{position:absolute;top:50%;left:50%;width:200px;-webkit-transform:translate(-50%, -50%);transform:translate(-50%, -50%);text-align:center}.ui-widget-empty__icon{font-size:120px}.ui-widget-empty__text{font-family:\"Frutiger-Light\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility}.ui-widget-empty__text strong{font-family:\"Frutiger-Bold\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility}.ui-widget-empty__link{margin-top:20px}";

class WidgetEmpty extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** icon name - must exist in the ui-icon list of available icons */
        this.icon = "";
        /** optional Link for the button */
        this.link = "";
        /** Text for Link Button */
        this.linkText = "";
    }
    render() {
        const baseClass = "ui-widget-empty";
        const { icon, link, linkText } = this;
        const hasLink = link !== "" && linkText !== "";
        return (h(Host, { class: baseClass }, h("ui-icon", { class: `${baseClass}__background`, name: icon }), h("div", { class: `${baseClass}__inner` }, h("ui-icon", { class: `${baseClass}__icon`, name: icon }), h("div", { class: `${baseClass}__text` }, h("slot", null), hasLink && (h("a", { href: link, class: `${baseClass}__link ui-button` }, linkText))))));
    }
    static get style() { return widgetEmptyCss; }
}

const widgetHeaderCss = ".ui-widget-header{font-family:\"Frutiger-Bold\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;font-size:20px;background:#285172;color:#fff;padding:10px 30px;width:100%;display:block;position:relative}.ui-widget-header a{margin-left:10px;text-decoration:none}.ui-widget-header .ui-icon{fill:#bbd03a}.ui-widget-header__menu{float:right}.ui-widget-header__menu-link{cursor:pointer}.ui-widget-header__menu-link .ui-icon{pointer-events:none}.ui-widget-header__menu-link.is-open::before{content:\"\";position:absolute;bottom:0;height:20px;width:20px;border:10px solid transparent;border-bottom:10px solid white;z-index:11}.ui-widget-header__menu-content{background-color:white;-webkit-box-shadow:0 10px 30px 0 rgba(0, 0, 0, 0.2);box-shadow:0 10px 30px 0 rgba(0, 0, 0, 0.2);position:absolute;right:30px;top:100%;min-width:200px;z-index:10;padding:30px;color:#131313}.ui-widget-header__menu-content.is-hidden{display:none}.ui-widget-header__menu-content .ui-select .ui-icon{fill:#131313}";

class WidgetHeader extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** url for the Link next to the title */
        this.url = "";
        /** text for the title attribute of the link */
        this.linkTitle = "";
        /** icon name of the icon to display left of the arrow in the title */
        this.icon = "documents";
        /** sets bool wether widget has a menu */
        this.hasMenu = false;
        /** wether the widget header menu is visible */
        this.menuVisible = false;
    }
    openMenu(e) {
        e.preventDefault();
        const el = e.target;
        el.classList.toggle("is-open");
        this.menuVisible = !this.menuVisible;
    }
    render() {
        return (h(Host, { class: "ui-widget-header" }, h("slot", { name: "headline" }), h("a", { href: this.url, title: this.linkTitle }, h("ui-icon", { name: this.icon }), "\u00A0", h("ui-icon", { name: "arrow-small-right" })), this.hasMenu && (h("div", { class: "ui-widget-header__menu" }, h("a", { href: "#", class: "ui-widget-header__menu-link", onClick: (e) => this.openMenu(e) }, h("ui-icon", { name: "cog" })), h("div", { class: `ui-widget-header__menu-content ${this.menuVisible ? "is-visible" : "is-hidden"}` }, h("slot", { name: "menu" }))))));
    }
    static get style() { return widgetHeaderCss; }
}

const buildUrl = (baseUrl, params = {}) => {
    if ((baseUrl === null || baseUrl === void 0 ? void 0 : baseUrl.length) < 1) {
        return "";
    }
    const urlWithParams = new URL(baseUrl);
    Object.keys(params).forEach((key) => {
        urlWithParams.searchParams.append(key, params[key]);
    });
    return urlWithParams.href;
};

/** Avoid running the same function twice within the specified timeframe. */
const debounce = (func, wait, immediate = false) => {
    let timeout;
    return function () {
        var context = this, args = arguments;
        clearTimeout(timeout);
        timeout = setTimeout(() => {
            timeout = null;
            if (!immediate)
                func.apply(context, args);
        }, wait);
        if (immediate && !timeout)
            func.apply(context, args);
    };
};

const widgetQuickOrderCss = ".ui-widget-quick-order{display:block}.ui-widget-quick-order .ui-widget-wrapper__body{overflow:visible}.ui-widget-quick-order__form{width:100%;display:-ms-flexbox;display:flex;-ms-flex-pack:center;justify-content:center;-ms-flex-align:center;align-items:center;-ms-flex-wrap:wrap;flex-wrap:wrap;padding:20px 30px 60px}.ui-widget-quick-order__text{width:100%;max-width:440px;margin:0 30px}.ui-widget-quick-order__number{width:140px;padding-top:34px;margin:0 30px}.ui-widget-quick-order__button{position:absolute;bottom:30px;right:30px}.ui-widget-quick-order--small .ui-widget-quick-order__text,.ui-widget-quick-order--medium .ui-widget-quick-order__text{margin:0}.ui-widget-quick-order--small .ui-widget-quick-order__number,.ui-widget-quick-order--medium .ui-widget-quick-order__number{position:absolute;left:30px;bottom:30px;margin:0}.ui-widget-quick-order--medium .ui-widget-quick-order__number{bottom:31px}";

class WidgetQuickOrder extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** URL where this widget can request the data */
        this.url = "";
        /** This holds the response from the API with all Information required to show the widget */
        this.data = null;
        /** width of the element - this helps with styling. Media queries can not be used because the width of the element can be independent from width of the window */
        this.width = 400;
    }
    componentWillLoad() {
        if (this.url === "") {
            console.warn("url needs to be supplied for WidgetQuickOrder");
            return;
        }
        api(this.url)
            .then((data) => {
            this.data = data;
        })
            .catch((error) => console.error(error));
        this.setWidth();
        window.onresize = debounce(() => this.setWidth(), 300);
    }
    setWidth() {
        var _a, _b;
        const width = (_b = (_a = this.domNode) === null || _a === void 0 ? void 0 : _a.parentElement) === null || _b === void 0 ? void 0 : _b.getBoundingClientRect().width;
        if (width > 0) {
            this.width = width;
        }
    }
    onSubmit(event) {
        event.preventDefault();
        const textInput = this.domNode.querySelector("input[type=text]");
        const numberInput = this.domNode.querySelector("input[type=number]");
        const text = textInput.value;
        const number = numberInput.value;
        const { amountParamName, materialNumberParamName, orderUrl, } = this.data;
        if ((orderUrl === null || orderUrl === void 0 ? void 0 : orderUrl.length) < 1 ||
            (amountParamName === null || amountParamName === void 0 ? void 0 : amountParamName.length) < 1 ||
            (materialNumberParamName === null || materialNumberParamName === void 0 ? void 0 : materialNumberParamName.length) < 1) {
            console.error("Widget Quick Order API needs to provide valid orderUrl, amountParamName and materialNumberParamName");
            return;
        }
        window.location.href = buildUrl(orderUrl, {
            [amountParamName]: number,
            [materialNumberParamName]: text,
        });
    }
    render() {
        if (this.data === null) {
            return null;
        }
        const baseClass = "ui-widget-quick-order";
        const { link, linkTitle, title, inputLabel, inputPlaceholder, suggestionUrl, orderButton, } = this.data;
        const { width } = this;
        const isSmall = width <= 380;
        const isMedium = width <= 740;
        return (h(Host, { class: {
                baseClass: true,
                [`${baseClass}--small`]: isSmall,
                [`${baseClass}--medium`]: isMedium,
            } }, h("ui-widget-wrapper", { url: link, linkTitle: linkTitle, headline: title, icon: "cart" }, h("div", { slot: "content" }, h("form", { class: `${baseClass}__form`, onSubmit: (event) => this.onSubmit(event) }, h("div", { class: `${baseClass}__text` }, h("ui-autosuggest-input", { label: inputLabel, placeholder: inputPlaceholder, url: suggestionUrl })), h("div", { class: `${baseClass}__number` }, h("ui-number-input", { min: "1", max: "99", initialValue: "1" })), h("div", { class: `${baseClass}__button` }, h("button", { type: "submit", class: {
                "ui-button ui-button--green": true,
                "ui-button--icon-only": isSmall,
            }, title: orderButton }, isSmall ? (h("ui-icon", { name: "cart" })) : (orderButton))))))));
    }
    get domNode() { return this; }
    static get watchers() { return {
        "url": ["componentWillLoad"]
    }; }
    static get style() { return widgetQuickOrderCss; }
}

const widgetServiceCallsCss = ".ui-widget-service-calls__item{display:-ms-inline-flexbox;display:inline-flex}.ui-widget-service-calls__item:nth-of-type(even){background:#eff0f4}";

class WidgetServiceCalls extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** URL where this widget can request the data */
        this.url = "";
        /** This holds the response from the API with all Information required to show the widget */
        this.data = null;
    }
    componentWillLoad() {
        if (this.url === "") {
            console.warn("url needs to be supplied for WidgetServiceCalls");
            return;
        }
        api(this.url)
            .then((data) => {
            this.data = data;
        })
            .catch((error) => console.error(error));
    }
    render() {
        if (this.data === null) {
            return null;
        }
        const baseClass = "ui-widget-service-calls";
        const { link, linkTitle, title, calls, noCallsText, createCall, createCallLink, messages, } = this.data;
        const hasCalls = (calls === null || calls === void 0 ? void 0 : calls.length) > 0;
        return (h(Host, { class: baseClass }, h("ui-widget-wrapper", { url: link, linkTitle: linkTitle, headline: title, icon: "wrench" }, h("div", { slot: "content" }, !hasCalls && (h("ui-widget-empty", { link: createCallLink, linkText: createCall, icon: "wrench-checkmark" }, h("div", { innerHTML: noCallsText }))), calls === null || calls === void 0 ? void 0 :
            calls.map((call) => {
                var _a, _b, _c;
                return (h("div", { class: `${baseClass}__item` }, h("ui-widget-service-calls-item", { headline: call.title, statusColor: (_a = call.status) === null || _a === void 0 ? void 0 : _a.color, statusText: (_b = call.status) === null || _b === void 0 ? void 0 : _b.text, statusIcon: (_c = call.status) === null || _c === void 0 ? void 0 : _c.icon, machineName: call.machineName, machineNumber: call.machineNumber, lastChange: call.lastChange, lastChangeLabel: messages === null || messages === void 0 ? void 0 : messages.lastChange, callIdLabel: messages === null || messages === void 0 ? void 0 : messages.callId, callId: call.callId, link: call.link, linkTitle: messages === null || messages === void 0 ? void 0 : messages.details, timeFormat: messages === null || messages === void 0 ? void 0 : messages.timeFormat })));
            })))));
    }
    static get watchers() { return {
        "url": ["componentWillLoad"]
    }; }
    static get style() { return widgetServiceCallsCss; }
}

const widgetServiceCallsItemCss = ".ui-widget-service-calls-item{display:inline-block;min-width:280px;max-width:280px;padding:20px 30px;position:relative}.ui-widget-service-calls-item .ui-text-tiny{text-transform:uppercase}.ui-widget-service-calls-item__header{padding-bottom:10px;margin-bottom:15px;border-bottom:1px solid rgba(19, 19, 19, 0.2)}.ui-widget-service-calls-item__headline{text-overflow:ellipsis;white-space:nowrap;overflow:hidden}.ui-widget-service-calls-item__status.ui-text-status{padding-left:2.8em;position:relative;min-height:33px;display:-ms-flexbox;display:flex;-ms-flex-pack:center;justify-content:center;-ms-flex-direction:column;flex-direction:column;margin-bottom:20px}.ui-widget-service-calls-item__status.ui-text-status .ui-icon{position:absolute;left:0;top:50%;-webkit-transform:translateY(-55%);transform:translateY(-55%);font-size:2.2em}.ui-widget-service-calls-item__label{margin-top:10px}.ui-widget-service-calls-item__bottom{margin-right:50px}.ui-widget-service-calls-item__button{position:absolute;bottom:30px;right:30px}";

class WidgetServiceCallsItem extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** Title of the service call */
        this.headline = "";
        /** name of the affected machine */
        this.machineName = "";
        /** Number of the affected machine */
        this.machineNumber = "";
        /** icon name for the status message - see available icons in ui-icon */
        this.statusIcon = "";
        /** color for the status message */
        this.statusColor = "";
        /** status message */
        this.statusText = "";
        /** Label for the call ID */
        this.callIdLabel = "";
        /** SIS ID of the service call */
        this.callId = "";
        /** Link to the detail page of the call */
        this.link = "";
        /** title attribute for the detail link */
        this.linkTitle = "";
        /** Label for last change */
        this.lastChangeLabel = "";
        /** UTC date/time of last change for ui-date-time */
        this.lastChange = "";
        /** Date/time format for ui-date-time */
        this.timeFormat = "";
    }
    getStatus(baseClass, statusText, statusColor, statusIcon = "circle-filled") {
        let classNames = `ui-text-status ${baseClass}__status`;
        if ((statusColor === null || statusColor === void 0 ? void 0 : statusColor.length) > 0) {
            classNames += ` ui-text-status--${statusColor.toLowerCase()}`;
        }
        return (h("div", { class: classNames }, h("ui-icon", { name: statusIcon }), statusText));
    }
    render() {
        const baseClass = "ui-widget-service-calls-item";
        const { headline, statusText, statusColor, machineName, machineNumber, statusIcon, callIdLabel, callId, link, linkTitle, lastChangeLabel, lastChange, timeFormat, } = this;
        return (h(Host, { class: baseClass }, h("div", { class: `${baseClass}__header` }, h("div", { class: `${baseClass}__headline ui-text-title ui-text-title--bold`, title: headline }, headline), h("div", { class: "ui-text-tiny" }, machineName), h("div", { class: "ui-text-tiny" }, machineNumber)), this.getStatus(baseClass, statusText, statusColor, statusIcon), h("div", { class: `${baseClass}__label ui-text-tiny ui-text-tiny--bold` }, callIdLabel), h("a", { class: "ui-text-link ui-text-link--green", href: link, title: linkTitle }, h("span", { class: "ui-text-tiny" }, callId)), h("div", { class: `${baseClass}__bottom` }, h("div", { class: `${baseClass}__label ui-text-tiny ui-text-tiny--bold` }, lastChangeLabel), h("div", { class: "ui-text-tiny" }, h("ui-date-time", { utc: lastChange, format: timeFormat }))), h("a", { class: `${baseClass}__button ui-button ui-button--icon-only`, href: link, title: linkTitle }, h("ui-icon", { name: "arrow-right" }))));
    }
    static get style() { return widgetServiceCallsItemCss; }
}

const sortByAlphabet = (a, b) => {
    const title1 = a;
    const title2 = b;
    let comparison = 0;
    if (title1 > title2) {
        comparison = 1;
    }
    else if (title1 < title2) {
        comparison = -1;
    }
    return comparison;
};
const sortByDate = (a, b) => {
    {
        return new Date(b).getTime() - new Date(a).getTime();
    }
};

const widgetShoppingListsCss = ".ui-widget-shopping-lists__item{display:-ms-inline-flexbox;display:inline-flex;height:100%}.ui-widget-shopping-lists__item:nth-of-type(even){background:#eff0f4}";

class WidgetShoppingLists extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** URL where this widget can request the data */
        this.url = "";
        /** This holds the response from the API with all Information required to show the widget */
        this.data = null;
        /** Array which holds all lists */
        this.listArray = [];
    }
    selectChange(event) {
        if (event.detail == "sortBy:alphabet" ||
            event.detail == "sortBy:alphabet:desc") {
            this.listArray.sort((a, b) => sortByAlphabet(a.title, b.title));
        }
        else if (event.detail == "sortBy:date" ||
            event.detail == "sortBy:date:desc") {
            this.listArray.sort((a, b) => sortByDate(a.lastChange, b.lastChange));
        }
        if (event.detail == "sortBy:alphabet:desc" ||
            event.detail == "sortBy:date:desc") {
            this.listArray.reverse();
        }
        // force rerender with following line
        this.listArray = [...this.listArray];
    }
    componentWillLoad() {
        if (this.url === "") {
            console.warn("url needs to be supplied for WidgetShoppingLists");
            return;
        }
        api(this.url)
            .then((data) => {
            this.data = data;
            this.listArray = this.data.lists;
        })
            .catch((error) => console.error(error));
    }
    render() {
        var _a;
        if (this.data === null) {
            return null;
        }
        const baseClass = "ui-widget-shopping-lists";
        const { link, linkTitle, title, lists, noListsText, createListLink, createList, messages, } = this.data;
        const hasLists = (lists === null || lists === void 0 ? void 0 : lists.length) > 0;
        return (h(Host, { class: baseClass }, h("ui-widget-wrapper", { url: link, linkTitle: linkTitle, headline: title, icon: "cart", hasMenu: true }, h("div", { slot: "menu" }, h("div", { class: "ui-text-tiny ui-text-tiny--bold ui-u-text-uppercase" }, messages === null || messages === void 0 ? void 0 : messages.sortByLabel), h("ui-select", { class: "ui-u-text-uppercase" }, h("option", { value: "sortBy:alphabet", selected: true }, messages === null || messages === void 0 ? void 0 : messages.alphabeticalLabel), h("option", { value: "sortBy:alphabet:desc" }, messages === null || messages === void 0 ? void 0 : messages.alphabeticalDescLabel), h("option", { value: "sortBy:date" }, messages === null || messages === void 0 ? void 0 : messages.recentlyChangedLabel), h("option", { value: "sortBy:date:desc" }, messages === null || messages === void 0 ? void 0 : messages.recentlyChangedAscLabel))), h("div", { slot: "content" }, !hasLists && (h("ui-widget-empty", { link: createListLink, linkText: createList, icon: "watchlist" }, h("div", { innerHTML: noListsText }))), (_a = this.listArray) === null || _a === void 0 ? void 0 :
            _a.map((list) => (h("div", { class: `${baseClass}__item` }, h("ui-widget-shopping-lists-item", { headline: list.title, lastChange: list.lastChange, lastChangeLabel: messages === null || messages === void 0 ? void 0 : messages.lastChange, listLink: list.listLink, listLinkTitle: messages === null || messages === void 0 ? void 0 : messages.details, articleLabel: messages === null || messages === void 0 ? void 0 : messages.articleLabel, addListToCartLink: list.addListToCartLink, addListToCartLinkTitle: messages === null || messages === void 0 ? void 0 : messages.addListToCart, timeFormat: messages === null || messages === void 0 ? void 0 : messages.timeFormat, amount: list.amount }))))))));
    }
    static get watchers() { return {
        "url": ["componentWillLoad"]
    }; }
    static get style() { return widgetShoppingListsCss; }
}

const widgetShoppingListsItemCss = ".ui-widget-shopping-lists-item{display:inline-block;min-width:280px;max-width:280px;padding:20px 30px;position:relative}.ui-widget-shopping-lists-item .ui-text-tiny{text-transform:uppercase}.ui-widget-shopping-lists-item__header{padding-bottom:20px;margin-bottom:15px}.ui-widget-shopping-lists-item__headline{text-overflow:ellipsis;white-space:nowrap;overflow:hidden;margin-bottom:25px}.ui-widget-shopping-lists-item__label{margin-top:10px}.ui-widget-shopping-lists-item__bottom{margin-right:50px}.ui-widget-shopping-lists-item__button{margin-bottom:10px}.ui-widget-shopping-lists-item .ui-button{width:100%;padding:13px}";

class WidgetShoppingListsItem extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** Title of the service call */
        this.headline = "";
        /** Total amount of items in a list  */
        this.amount = 0;
        /** 'Article' label  */
        this.articleLabel = "";
        /** Number of a list */
        this.listNumber = "";
        /** show details link */
        this.listLink = "";
        /** title attribute for the detail link */
        this.listLinkTitle = "";
        /** show details link */
        this.addListToCartLink = "";
        /** title attribute for the detail link */
        this.addListToCartLinkTitle = "";
        /** Label for last change */
        this.lastChangeLabel = "";
        /** UTC date/time of last change for ui-date-time */
        this.lastChange = "";
        /** Date/time format for ui-date-time */
        this.timeFormat = "";
    }
    render() {
        const baseClass = "ui-widget-shopping-lists-item";
        const { headline, listLink, listLinkTitle, addListToCartLink, addListToCartLinkTitle, lastChangeLabel, lastChange, timeFormat, amount, articleLabel, } = this;
        return (h(Host, { class: baseClass }, h("div", { class: `${baseClass}__header` }, h("div", { class: `${baseClass}__headline ui-text-title ui-text-title--bold`, title: headline }, headline), h("div", { class: "ui-text-tiny" }, amount, " ", articleLabel), h("div", { class: "ui-text-tiny" }, lastChangeLabel, ":", h("strong", null, "\u00A0", h("ui-date-time", { utc: lastChange, format: timeFormat })))), h("a", { class: `${baseClass}__button ui-button`, href: listLink, title: listLinkTitle }, listLinkTitle), h("a", { class: "ui-button ui-button--green", href: addListToCartLink, title: addListToCartLinkTitle }, addListToCartLinkTitle)));
    }
    static get style() { return widgetShoppingListsItemCss; }
}

const widgetTrackCss = ".ui-widget-track__order-item{display:-ms-inline-flexbox;display:inline-flex}.ui-widget-track__order-item:nth-of-type(even){background:#eff0f4}";

class WidgetTrack extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** URL where this widget can request the data */
        this.url = "";
        /** This holds the response from the API with all Information required to show the widget */
        this.data = null;
    }
    componentWillLoad() {
        if (this.url === "") {
            console.warn("url needs to be supplied for WidgetTrack");
            return;
        }
        api(this.url)
            .then((data) => {
            this.data = data;
        })
            .catch((error) => console.error(error));
    }
    render() {
        if (this.data === null) {
            return null;
        }
        const baseClass = "ui-widget-track";
        const { link, linkTitle, title, orders, readMore, noOrdersText, } = this.data;
        const hasOrders = (orders === null || orders === void 0 ? void 0 : orders.length) > 0;
        const linkItem = hasOrders && typeof readMore === "object" ? (h("div", { class: `${baseClass}__order-item` }, h("ui-widget-track-link-item", { headline: readMore.title, link: readMore.link, linkLabel: readMore.linkText }))) : null;
        return (h(Host, { class: baseClass }, h("ui-widget-wrapper", { url: link, linkTitle: linkTitle, headline: title }, h("div", { slot: "content" }, !hasOrders && (h("ui-widget-empty", { icon: "order-status-package-checkmark" }, h("div", { innerHTML: noOrdersText }))), orders === null || orders === void 0 ? void 0 :
            orders.map((order) => (h("div", { class: `${baseClass}__order-item` }, order.shipments.map((shipment) => {
                var _a, _b, _c;
                return (h("ui-widget-track-delivery-item", { headline: shipment.title, statusColor: shipment.status.color, statusText: shipment.status.text, label: shipment.label, date: shipment.date, orderLink: order.orderLink, orderLinkTitle: order.orderLinkTitle, orderNumber: order.orderNumber, trackingNumber: (_a = shipment.tracking) === null || _a === void 0 ? void 0 : _a.number, trackingLink: (_b = shipment.tracking) === null || _b === void 0 ? void 0 : _b.link, trackingLinkTitle: (_c = shipment.tracking) === null || _c === void 0 ? void 0 : _c.linkTitle }));
            })))), linkItem))));
    }
    static get watchers() { return {
        "url": ["componentWillLoad"]
    }; }
    static get style() { return widgetTrackCss; }
}

const widgetTrackDeliveryItemCss = ".ui-widget-track-delivery-item{display:inline-block;min-width:248px;max-width:248px;padding:20px 30px}.ui-widget-track-delivery-item__order-number{font-family:\"Frutiger-Light\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;margin-bottom:15px;padding-bottom:5px;font-size:20px;border-bottom:1px solid rgba(19, 19, 19, 0.2);position:relative;text-decoration:none;color:#131313;display:block}.ui-widget-track-delivery-item__order-number .ui-icon{right:19px;top:7px;position:absolute;font-size:14px}.ui-widget-track-delivery-item~.ui-widget-track-delivery-item .ui-widget-track-delivery-item__order-number{margin-left:-60px}.ui-widget-track-delivery-item~.ui-widget-track-delivery-item .ui-widget-track-delivery-item__order-number__content,.ui-widget-track-delivery-item~.ui-widget-track-delivery-item .ui-widget-track-delivery-item__order-number__icon{visibility:hidden}.ui-widget-track-delivery-item__status{margin-top:5px}.ui-widget-track-delivery-item__tracking-link{display:block;margin-top:30px}.ui-widget-track-delivery-item__label{margin-top:20px}";

class WidgetTrackDeliveryItem extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** Number of the delivery */
        this.headline = "";
        /** Current status message */
        this.statusText = "";
        /** color for the current status */
        this.statusColor = "";
        /** Headline over the shipping section */
        this.label = "";
        /** formatted date or placeholder text */
        this.date = "";
        /** Number of the order */
        this.orderNumber = "";
        /** Link to the order detail page */
        this.orderLink = "";
        /** Title attribute for Link to the order detail page */
        this.orderLinkTitle = "";
        /** Tracking number for a single shipment */
        this.trackingNumber = "";
        /** Link to the tracking page */
        this.trackingLink = "";
        /** Linktext for the tracking link */
        this.trackingLinkTitle = "";
    }
    getStatus(statusText, statusColor, baseClass) {
        let classNames = `ui-text-status ${baseClass}__status`;
        if ((statusColor === null || statusColor === void 0 ? void 0 : statusColor.length) > 0) {
            classNames += ` ui-text-status--${statusColor.toLowerCase()}`;
        }
        return (h("div", { class: classNames }, h("ui-icon", { name: "circle-filled" }), statusText));
    }
    render() {
        const baseClass = "ui-widget-track-delivery-item";
        const { orderNumber, orderLink, orderLinkTitle, headline, statusText, statusColor, label, date, trackingNumber, trackingLink, trackingLinkTitle, } = this;
        const trackingInformation = trackingLink === "" ? null : (h("div", null, trackingNumber && (h("div", { class: "ui-text-tiny ui-u-text-uppercase" }, trackingNumber)), trackingLink && (h("a", { class: `${baseClass}__tracking-link ui-text-link ui-text-link--green`, href: trackingLink, target: "_blank", rel: "noopener noreferrer" }, trackingLinkTitle, " ", h("ui-icon", { name: "arrow-small-right" })))));
        return (h(Host, { class: baseClass }, h("a", { class: `${baseClass}__order-number`, href: orderLink, title: orderLinkTitle }, h("span", { class: `${baseClass}__order-number__content` }, orderNumber), h("ui-icon", { class: `${baseClass}__order-number__icon`, name: "arrow-right" })), headline && (h("div", { class: `${baseClass}__headline ui-text-tiny ui-text-tiny--bold ui-u-text-uppercase` }, headline)), this.getStatus(statusText, statusColor, baseClass), label && (h("div", { class: `${baseClass}__label ui-text-tiny ui-text-tiny--bold ui-u-text-uppercase` }, label)), date && (h("div", { class: "ui-text-tiny ui-u-text-uppercase" }, date)), trackingInformation));
    }
    static get style() { return widgetTrackDeliveryItemCss; }
}

const widgetTrackLinkItemCss = ".ui-widget-track-link-item{display:inline-block;min-width:248px;max-width:248px;padding:20px 30px;position:relative}.ui-widget-track-link-item__inner{position:absolute;width:calc(100% - 40px);left:0;top:50%;right:0;margin:auto;-webkit-transform:translateY(-50%);transform:translateY(-50%);text-align:center}.ui-widget-track-link-item__icon{font-size:60px}.ui-widget-track-link-item__headline{font-family:\"Frutiger-Bold\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;color:#131313;margin:5px 0 15px}";

class WidgetTrackLinkItem extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** Text above the button link */
        this.headline = "";
        /** link for the button link */
        this.link = "";
        /** Text on the button link */
        this.linkLabel = "";
    }
    render() {
        const baseClass = "ui-widget-track-link-item";
        const { headline, link, linkLabel } = this;
        return (h(Host, { class: baseClass }, h("div", { class: `${baseClass}__inner` }, h("ui-icon", { class: `${baseClass}__icon`, name: "order-status-package-checkmark" }), h("div", { class: `${baseClass}__headline` }, headline), h("a", { class: "ui-button", href: link }, linkLabel))));
    }
    static get style() { return widgetTrackLinkItemCss; }
}

const widgetWrapperCss = ".ui-widget-wrapper{font-family:\"Frutiger-Roman\", sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;-webkit-box-shadow:0 7px 22px rgba(19, 19, 19, 0.05);box-shadow:0 7px 22px rgba(19, 19, 19, 0.05);display:block}.ui-widget-wrapper__body{display:-ms-flexbox;display:flex;overflow-x:auto;min-height:289px;position:relative}";

class WidgetWrapper extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /** url for the Link next to the title */
        this.url = "";
        /** text for the title attribute of the link */
        this.linkTitle = "";
        /** text for the title */
        this.headline = "";
        /** icon name of the icon to display left of the arrow in the title */
        this.icon = "documents";
        /** sets bool wether widget has a menu */
        this.hasMenu = false;
    }
    render() {
        return (h(Host, { class: "ui-widget-wrapper" }, h("ui-widget-header", { url: this.url, linkTitle: this.linkTitle, icon: this.icon, hasMenu: this.hasMenu }, h("span", { slot: "headline" }, this.headline), h("div", { slot: "menu" }, h("slot", { name: "menu" }))), h("div", { class: "ui-widget-wrapper__body" }, h("slot", { name: "content" }))));
    }
    static get style() { return widgetWrapperCss; }
}

const UiAutosuggestInput = /*@__PURE__*/proxyCustomElement(AutosuggestInput, [0,"ui-autosuggest-input",{"placeholder":[1],"name":[1],"inputId":[1,"input-id"],"label":[1],"url":[1],"suggestions":[32],"input":[32],"isHidden":[32],"id":[32]}]);
const UiCheckbox = /*@__PURE__*/proxyCustomElement(Checkbox, [0,"ui-checkbox",{"value":[513],"label":[513]}]);
const UiCheckboxListItem = /*@__PURE__*/proxyCustomElement(CheckboxListItem, [4,"ui-checkbox-list-item",{"value":[513],"label":[513]}]);
const UiDateTime = /*@__PURE__*/proxyCustomElement(DateTime, [0,"ui-date-time",{"utc":[1],"format":[1],"formattedDateTime":[32]}]);
const UiDropdown = /*@__PURE__*/proxyCustomElement(Dropdown, [4,"ui-dropdown",{"label":[513],"name":[513],"filterable":[516],"isOpen":[32]},[[32,"click","handleBodyClick"]]]);
const UiFilter = /*@__PURE__*/proxyCustomElement(Filter, [4,"ui-filter",{"endpoint":[513],"filterValues":[32]},[[0,"remove","tagRemovedHandler"]]]);
const UiIcon = /*@__PURE__*/proxyCustomElement(Icon, [0,"ui-icon",{"name":[513],"svgContent":[32]}]);
const UiList = /*@__PURE__*/proxyCustomElement(List, [4,"ui-list",{"filterable":[516],"items":[32],"filterString":[32]}]);
const UiNumberInput = /*@__PURE__*/proxyCustomElement(NumberInput, [0,"ui-number-input",{"name":[1],"initialValue":[1,"initial-value"],"step":[1],"max":[1],"min":[1],"value":[32],"minValue":[32],"maxValue":[32],"stepValue":[32]}]);
const UiScrollToTopButton = /*@__PURE__*/proxyCustomElement(ScrollToTopButton, [0,"ui-scroll-to-top-button"]);
const UiSelect = /*@__PURE__*/proxyCustomElement(Select, [4,"ui-select"]);
const UiSuggestItem = /*@__PURE__*/proxyCustomElement(SuggestItem, [0,"ui-suggest-item",{"input":[1],"text":[1],"subline":[1],"image":[1]}]);
const UiTab = /*@__PURE__*/proxyCustomElement(Tab, [4,"ui-tab",{"name":[513],"tabId":[513,"tab-id"],"active":[32]},[[16,"ui-setActiveTab","setActiveTab"]]]);
const UiTabButton = /*@__PURE__*/proxyCustomElement(TabButton, [0,"ui-tab-button",{"name":[513],"activeTab":[513,"active-tab"],"tabId":[513,"tab-id"],"active":[32]}]);
const UiTabContainer = /*@__PURE__*/proxyCustomElement(TabContainer, [4,"ui-tab-container",{"activeTabId":[1,"active-tab-id"]}]);
const UiTag = /*@__PURE__*/proxyCustomElement(Tag, [4,"ui-tag",{"reference":[513]}]);
const UiWidgetEmpty = /*@__PURE__*/proxyCustomElement(WidgetEmpty, [4,"ui-widget-empty",{"icon":[1],"link":[1],"linkText":[1,"link-text"]}]);
const UiWidgetHeader = /*@__PURE__*/proxyCustomElement(WidgetHeader, [4,"ui-widget-header",{"url":[1],"linkTitle":[1,"link-title"],"icon":[1],"hasMenu":[4,"has-menu"],"menuVisible":[32]}]);
const UiWidgetQuickOrder = /*@__PURE__*/proxyCustomElement(WidgetQuickOrder, [0,"ui-widget-quick-order",{"url":[1],"data":[32],"width":[32]}]);
const UiWidgetServiceCalls = /*@__PURE__*/proxyCustomElement(WidgetServiceCalls, [0,"ui-widget-service-calls",{"url":[1],"data":[32]}]);
const UiWidgetServiceCallsItem = /*@__PURE__*/proxyCustomElement(WidgetServiceCallsItem, [0,"ui-widget-service-calls-item",{"headline":[1],"machineName":[1,"machine-name"],"machineNumber":[1,"machine-number"],"statusIcon":[1,"status-icon"],"statusColor":[1,"status-color"],"statusText":[1,"status-text"],"callIdLabel":[1,"call-id-label"],"callId":[1,"call-id"],"link":[1],"linkTitle":[1,"link-title"],"lastChangeLabel":[1,"last-change-label"],"lastChange":[1,"last-change"],"timeFormat":[1,"time-format"]}]);
const UiWidgetShoppingLists = /*@__PURE__*/proxyCustomElement(WidgetShoppingLists, [0,"ui-widget-shopping-lists",{"url":[1],"data":[32],"listArray":[32]},[[16,"ui-selectChange","selectChange"]]]);
const UiWidgetShoppingListsItem = /*@__PURE__*/proxyCustomElement(WidgetShoppingListsItem, [0,"ui-widget-shopping-lists-item",{"headline":[1],"amount":[2],"articleLabel":[1,"article-label"],"listNumber":[1,"list-number"],"listLink":[1,"list-link"],"listLinkTitle":[1,"list-link-title"],"addListToCartLink":[1,"add-list-to-cart-link"],"addListToCartLinkTitle":[1,"add-list-to-cart-link-title"],"lastChangeLabel":[1,"last-change-label"],"lastChange":[1,"last-change"],"timeFormat":[1,"time-format"]}]);
const UiWidgetTrack = /*@__PURE__*/proxyCustomElement(WidgetTrack, [0,"ui-widget-track",{"url":[1],"data":[32]}]);
const UiWidgetTrackDeliveryItem = /*@__PURE__*/proxyCustomElement(WidgetTrackDeliveryItem, [0,"ui-widget-track-delivery-item",{"headline":[1],"statusText":[1,"status-text"],"statusColor":[1,"status-color"],"label":[1],"date":[1],"orderNumber":[1,"order-number"],"orderLink":[1,"order-link"],"orderLinkTitle":[1,"order-link-title"],"trackingNumber":[1,"tracking-number"],"trackingLink":[1,"tracking-link"],"trackingLinkTitle":[1,"tracking-link-title"]}]);
const UiWidgetTrackLinkItem = /*@__PURE__*/proxyCustomElement(WidgetTrackLinkItem, [0,"ui-widget-track-link-item",{"headline":[1],"link":[1],"linkLabel":[1,"link-label"]}]);
const UiWidgetWrapper = /*@__PURE__*/proxyCustomElement(WidgetWrapper, [4,"ui-widget-wrapper",{"url":[1],"linkTitle":[1,"link-title"],"headline":[1],"icon":[1],"hasMenu":[4,"has-menu"]}]);
const defineCustomElements = () => {
  [
  UiAutosuggestInput,
  UiCheckbox,
  UiCheckboxListItem,
  UiDateTime,
  UiDropdown,
  UiFilter,
  UiIcon,
  UiList,
  UiNumberInput,
  UiScrollToTopButton,
  UiSelect,
  UiSuggestItem,
  UiTab,
  UiTabButton,
  UiTabContainer,
  UiTag,
  UiWidgetEmpty,
  UiWidgetHeader,
  UiWidgetQuickOrder,
  UiWidgetServiceCalls,
  UiWidgetServiceCallsItem,
  UiWidgetShoppingLists,
  UiWidgetShoppingListsItem,
  UiWidgetTrack,
  UiWidgetTrackDeliveryItem,
  UiWidgetTrackLinkItem,
  UiWidgetWrapper
  ].forEach(cmp => customElements.define(cmp.is, cmp));
};

export { UiAutosuggestInput, UiCheckbox, UiCheckboxListItem, UiDateTime, UiDropdown, UiFilter, UiIcon, UiList, UiNumberInput, UiScrollToTopButton, UiSelect, UiSuggestItem, UiTab, UiTabButton, UiTabContainer, UiTag, UiWidgetEmpty, UiWidgetHeader, UiWidgetQuickOrder, UiWidgetServiceCalls, UiWidgetServiceCallsItem, UiWidgetShoppingLists, UiWidgetShoppingListsItem, UiWidgetTrack, UiWidgetTrackDeliveryItem, UiWidgetTrackLinkItem, UiWidgetWrapper, defineCustomElements };
